# Release History

## 1.0.0 (2024-01-26)

### Features Added

  - Model DataProduct has a new parameter properties
  - Model DataProductUpdate has a new parameter properties
  - Model DataProductsCatalog has a new parameter properties
  - Model DataType has a new parameter properties
  - Model DataTypeUpdate has a new parameter properties

### Breaking Changes

  - Model DataProduct no longer has parameter available_minor_versions
  - Model DataProduct no longer has parameter consumption_endpoints
  - Model DataProduct no longer has parameter current_minor_version
  - Model DataProduct no longer has parameter customer_encryption_key
  - Model DataProduct no longer has parameter customer_managed_key_encryption_enabled
  - Model DataProduct no longer has parameter documentation
  - Model DataProduct no longer has parameter key_vault_url
  - Model DataProduct no longer has parameter major_version
  - Model DataProduct no longer has parameter managed_resource_group_configuration
  - Model DataProduct no longer has parameter networkacls
  - Model DataProduct no longer has parameter owners
  - Model DataProduct no longer has parameter private_links_enabled
  - Model DataProduct no longer has parameter product
  - Model DataProduct no longer has parameter provisioning_state
  - Model DataProduct no longer has parameter public_network_access
  - Model DataProduct no longer has parameter publisher
  - Model DataProduct no longer has parameter purview_account
  - Model DataProduct no longer has parameter purview_collection
  - Model DataProduct no longer has parameter redundancy
  - Model DataProduct no longer has parameter resource_guid
  - Model DataProductUpdate no longer has parameter current_minor_version
  - Model DataProductUpdate no longer has parameter owners
  - Model DataProductUpdate no longer has parameter private_links_enabled
  - Model DataProductUpdate no longer has parameter purview_account
  - Model DataProductUpdate no longer has parameter purview_collection
  - Model DataProductsCatalog no longer has parameter provisioning_state
  - Model DataProductsCatalog no longer has parameter publishers
  - Model DataType no longer has parameter database_cache_retention
  - Model DataType no longer has parameter database_retention
  - Model DataType no longer has parameter provisioning_state
  - Model DataType no longer has parameter state
  - Model DataType no longer has parameter state_reason
  - Model DataType no longer has parameter storage_output_retention
  - Model DataType no longer has parameter visualization_url
  - Model DataTypeUpdate no longer has parameter database_cache_retention
  - Model DataTypeUpdate no longer has parameter database_retention
  - Model DataTypeUpdate no longer has parameter state
  - Model DataTypeUpdate no longer has parameter storage_output_retention

## 1.0.0b1 (2023-11-28)

* Initial Release
